==> aws-java-sdk-1.4.1-sources.jar: com/amazonaws/services/opsworks/model/AutoScalingType.java <==
/*
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.opsworks.model;

/**
 * Auto Scaling Type
 */
public enum AutoScalingType {
    
    AlwaysRunning("AlwaysRunning"),
    TimeBasedAutoScaling("TimeBasedAutoScaling"),
    LoadBasedAutoScaling("LoadBasedAutoScaling");

    private String value;

    private AutoScalingType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return AutoScalingType corresponding to the value
     */
    public static AutoScalingType fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("AlwaysRunning".equals(value)) {
            return AutoScalingType.AlwaysRunning;
        } else if ("TimeBasedAutoScaling".equals(value)) {
            return AutoScalingType.TimeBasedAutoScaling;
        } else if ("LoadBasedAutoScaling".equals(value)) {
            return AutoScalingType.LoadBasedAutoScaling;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-java-sdk-1.4.5-sources.jar: com/amazonaws/services/opsworks/model/AutoScalingType.java <==
/*
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.opsworks.model;

/**
 * Auto Scaling Type
 */
public enum AutoScalingType {
    
    Load("load"),
    Timer("timer");

    private String value;

    private AutoScalingType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return AutoScalingType corresponding to the value
     */
    public static AutoScalingType fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("load".equals(value)) {
            return AutoScalingType.Load;
        } else if ("timer".equals(value)) {
            return AutoScalingType.Timer;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
